@@ -315,7 +315,7 @@ class SimpleRecognizerWidget(RecognizerWidgetBase):
         if not self._ready:
             return
 
-        writing = self._canvas.get_writing()
+        writing = self._canvas.get_writing().copy()
 
         if writing.get_n_strokes() > 0:
             candidates = self._recognizer.recognize(writing, n=9)
@@ -617,7 +617,8 @@ class CandidatePopup(gtk.Window):
         self._chartable.set_characters(self._candidates)
         self._chartable.set_layout(CharTable.LAYOUT_HORIZONTAL)
         max_width, max_height = self._chartable.get_max_char_size()
-        self._chartable.set_size_request(max_width*3, max_height*3)
+        self._chartable.set_size_request(int(max_width*3.5),
+                                         int(max_height*3.5))
         frame.add(self._chartable)
 
         self.connect("button-press-event", self._on_button_press)
